@@ -141,8 +141,14 @@ module Stomp
             @failure = $!
             used_socket = nil
             raise unless @reliable
+            raise if @failure.is_a?(Stomp::Error::LoggerConnectionError)
             if @logger && @logger.respond_to?(:on_connectfail)
-              @logger.on_connectfail(log_params)
+              # on_connectfail may raise
+              begin
+                @logger.on_connectfail(log_params)
+              rescue Exception => aex
+                raise if aex.is_a?(Stomp::Error::LoggerConnectionError)
+              end
             else
               $stderr.print "connect to #{@host} failed: #{$!} will retry(##{@connection_attempts}) in #{@reconnect_delay}\n"
             end
@@ -500,14 +506,14 @@ module Stomp
             content_length = message_header.match /content-length\s?:\s?(\d+)\s?\n/
             message_body = ''
 
-            # If it does, reads the specified amount of bytes
-            char = ''
+            # If content_length is present, read the specified amount of bytes
             if content_length
               message_body = read_socket.read content_length[1].to_i
               raise Stomp::Error::InvalidMessageLength unless parse_char(read_socket.getc) == "\0"
-            # Else reads, the rest of the message until the first \0
+            # Else read the rest of the message until the first \0
             else
-              message_body += char while (char = parse_char(read_socket.getc)) != "\0"
+              message_body = read_socket.readline("\0")
+              message_body.chop!
             end
 
             # If the buffer isn't empty, reads trailing new lines.
@@ -629,93 +635,106 @@ module Stomp
 
       def open_ssl_socket
         require 'openssl' unless defined?(OpenSSL)
-        ctx = OpenSSL::SSL::SSLContext.new
-        ctx.verify_mode = OpenSSL::SSL::VERIFY_NONE # Assume for now
-        #
-        # Note: if a client uses :ssl => true this results in the gem using
-        # the _default_ Ruby ciphers list.  This is _known_ to fail in later
-        # Ruby releases.  The gem provides a default cipher list that may
-        # function in these cases.  To use this connect with:
-        # * :ssl => Stomp::SSLParams.new
-        # * :ssl => Stomp::SSLParams.new(..., :ciphers => Stomp::DEFAULT_CIPHERS)
-        #
-        # If connecting with an SSLParams instance, and the _default_ Ruby
-        # ciphers list is required, use:
-        # * :ssl => Stomp::SSLParams.new(..., :use_ruby_ciphers => true)
-        #
-        # If a custom ciphers list is required, connect with:
-        # * :ssl => Stomp::SSLParams.new(..., :ciphers => custom_ciphers_list)
-        #
-        if @ssl != true
+        begin # Any raised SSL exceptions
+          ctx = OpenSSL::SSL::SSLContext.new
+          ctx.verify_mode = OpenSSL::SSL::VERIFY_NONE # Assume for now
           #
-          # Here @ssl is:
-          # * an instance of Stomp::SSLParams
-          # Control would not be here if @ssl == false or @ssl.nil?.
+          # Note: if a client uses :ssl => true this results in the gem using
+          # the _default_ Ruby ciphers list.  This is _known_ to fail in later
+          # Ruby releases.  The gem provides a default cipher list that may
+          # function in these cases.  To use this connect with:
+          # * :ssl => Stomp::SSLParams.new
+          # * :ssl => Stomp::SSLParams.new(..., :ciphers => Stomp::DEFAULT_CIPHERS)
           #
+          # If connecting with an SSLParams instance, and the _default_ Ruby
+          # ciphers list is required, use:
+          # * :ssl => Stomp::SSLParams.new(..., :use_ruby_ciphers => true)
+          #
+          # If a custom ciphers list is required, connect with:
+          # * :ssl => Stomp::SSLParams.new(..., :ciphers => custom_ciphers_list)
+          #
+          if @ssl != true
+            #
+            # Here @ssl is:
+            # * an instance of Stomp::SSLParams
+            # Control would not be here if @ssl == false or @ssl.nil?.
+            #
 
-          # Back reference the SSLContext
-          @ssl.ctx = ctx
+            # Back reference the SSLContext
+            @ssl.ctx = ctx
 
-          # Server authentication parameters if required
-          if @ssl.ts_files
-            ctx.verify_mode = OpenSSL::SSL::VERIFY_PEER
-            truststores = OpenSSL::X509::Store.new
-            fl = @ssl.ts_files.split(",")
-            fl.each do |fn|
-              # Add next cert file listed
-              raise Stomp::Error::SSLNoTruststoreFileError if !File::exists?(fn)
-              truststores.add_file(fn)
+            # Server authentication parameters if required
+            if @ssl.ts_files
+              ctx.verify_mode = OpenSSL::SSL::VERIFY_PEER
+              truststores = OpenSSL::X509::Store.new
+              fl = @ssl.ts_files.split(",")
+              fl.each do |fn|
+                # Add next cert file listed
+                raise Stomp::Error::SSLNoTruststoreFileError if !File::exists?(fn)
+                raise Stomp::Error::SSLUnreadableTruststoreFileError if !File::readable?(fn)
+                truststores.add_file(fn)
+              end
+              ctx.cert_store = truststores
+            end
+
+            # Client authentication parameters
+            # Both cert file and key file must be present or not, it can not be a mix
+            raise Stomp::Error::SSLClientParamsError if @ssl.cert_file.nil? && !@ssl.key_file.nil?
+            raise Stomp::Error::SSLClientParamsError if !@ssl.cert_file.nil? && @ssl.key_file.nil?
+            if @ssl.cert_file # Any check will do here
+              raise Stomp::Error::SSLNoCertFileError if !File::exists?(@ssl.cert_file)
+              raise Stomp::Error::SSLUnreadableCertFileError if !File::readable?(@ssl.cert_file)
+              ctx.cert = OpenSSL::X509::Certificate.new(File.open(@ssl.cert_file))
+              raise Stomp::Error::SSLNoKeyFileError if !File::exists?(@ssl.key_file)
+              raise Stomp::Error::SSLUnreadableKeyFileError if !File::readable?(@ssl.key_file)
+              ctx.key  = OpenSSL::PKey::RSA.new(File.open(@ssl.key_file))
+            end
+
+            # Cipher list
+            if !@ssl.use_ruby_ciphers # No Ruby ciphers (the default)
+              if @ssl.ciphers # User ciphers list?
+                ctx.ciphers = @ssl.ciphers # Accept user supplied ciphers
+              else
+                ctx.ciphers = Stomp::DEFAULT_CIPHERS # Just use Stomp defaults
+              end
             end
-            ctx.cert_store = truststores
           end
 
-          # Client authentication parameters
-          # Both cert file and key file must be present or not, it can not be a mix
-          raise Stomp::Error::SSLClientParamsError if @ssl.cert_file.nil? && !@ssl.key_file.nil?
-          raise Stomp::Error::SSLClientParamsError if !@ssl.cert_file.nil? && @ssl.key_file.nil?
-          if @ssl.cert_file # Any check will do here
-            raise Stomp::Error::SSLNoCertFileError if !File::exists?(@ssl.cert_file)
-            ctx.cert = OpenSSL::X509::Certificate.new(File.open(@ssl.cert_file))
-            raise Stomp::Error::SSLNoKeyFileError if !File::exists?(@ssl.key_file)
-            ctx.key  = OpenSSL::PKey::RSA.new(File.open(@ssl.key_file))
+          #
+          ssl = nil
+          if @logger && @logger.respond_to?(:on_ssl_connecting)
+            @logger.on_ssl_connecting(log_params)
           end
 
-          # Cipher list
-          if !@ssl.use_ruby_ciphers # No Ruby ciphers (the default)
-            if @ssl.ciphers # User ciphers list?
-              ctx.ciphers = @ssl.ciphers # Accept user supplied ciphers
+        	Timeout::timeout(@connect_timeout, Stomp::Error::SocketOpenTimeout) do
+          	ssl = OpenSSL::SSL::SSLSocket.new(open_tcp_socket, ctx)
+        	end
+          def ssl.ready?
+            ! @rbuffer.empty? || @io.ready?
+          end
+          ssl.connect
+          if @ssl != true
+            # Pass back results if possible
+            if RUBY_VERSION =~ /1\.8\.[56]/
+              @ssl.verify_result = "N/A for Ruby #{RUBY_VERSION}"
             else
-              ctx.ciphers = Stomp::DEFAULT_CIPHERS # Just use Stomp defaults
+              @ssl.verify_result = ssl.verify_result
             end
+            @ssl.peer_cert = ssl.peer_cert
           end
-        end
-
-        #
-        ssl = nil
-        if @logger && @logger.respond_to?(:on_ssl_connecting)
-          @logger.on_ssl_connecting(log_params)
-        end
-
-      	Timeout::timeout(@connect_timeout, Stomp::Error::SocketOpenTimeout) do
-        	ssl = OpenSSL::SSL::SSLSocket.new(open_tcp_socket, ctx)
-      	end
-        def ssl.ready?
-          ! @rbuffer.empty? || @io.ready?
-        end
-        ssl.connect
-        if @ssl != true
-          # Pass back results if possible
-          if RUBY_VERSION =~ /1\.8\.[56]/
-            @ssl.verify_result = "N/A for Ruby #{RUBY_VERSION}"
-          else
-            @ssl.verify_result = ssl.verify_result
+          if @logger && @logger.respond_to?(:on_ssl_connected)
+            @logger.on_ssl_connected(log_params)
           end
-          @ssl.peer_cert = ssl.peer_cert
+          ssl
+        rescue Exception => ex
+          if @logger && @logger.respond_to?(:on_ssl_connectfail)
+            lp = log_params.clone
+            lp[:ssl_exception] = ex
+            @logger.on_ssl_connectfail(lp)
+          end
+          #
+          raise # Reraise
         end
-        if @logger && @logger.respond_to?(:on_ssl_connected)
-          @logger.on_ssl_connected(log_params)
-        end
-        ssl
       end
 
       def close_socket
